Package: provParseR
Title: Pulls Information from Prov.Json Files
Version: 1.0
Date: 2022-08-08
Authors@R: c(
    person("Orenna", "Brand", email = "o.brand@columbia.edu", role = "aut"),
    person("Joseph", "Wonsil", email = "jwonsil@carthage.edu", role = "aut"),
    person("Emery", "Boose", email = "boose@fas.harvard.edu", role = "aut"),
    person("Barbara", "Lerner", email = "blerner@mtholyoke.edu", role = "cre")
    )
Description: R functions to access provenance information collected by 'rdt' or 
    'rdtLite'.  The information is stored inside a 'ProvInfo' object and can be 
    accessed through a collection of functions that will return the requested 
    data. The exact format of the JSON created by 'rdt' and 'rdtLite' is described 
    in <https://github.com/End-to-end-provenance/ExtendedProvJson>.
Depends: R (>= 3.3)
License: GPL-3 | file LICENSE
Encoding: UTF-8
Imports: jsonlite, methods
Suggests: testthat
URL: https://github.com/End-to-end-provenance
RoxygenNote: 7.2.0
NeedsCompilation: no
Packaged: 2022-08-12 20:10:02 UTC; blerner
Author: Orenna Brand [aut],
  Joseph Wonsil [aut],
  Emery Boose [aut],
  Barbara Lerner [cre]
Maintainer: Barbara Lerner <blerner@mtholyoke.edu>
Repository: CRAN
Date/Publication: 2022-08-15 22:20:05 UTC
Built: R 4.6.0; ; 2026-04-25 21:22:02 UTC; unix
