# Generated by roxygen2: do not edit by hand

export(get.args)
export(get.data.nodes)
export(get.data.proc)
export(get.environment)
export(get.error.nodes)
export(get.func.lib)
export(get.func.nodes)
export(get.func.proc)
export(get.input.files)
export(get.libs)
export(get.output.files)
export(get.preexisting)
export(get.proc.data)
export(get.proc.nodes)
export(get.proc.proc)
export(get.saved.scripts)
export(get.scripts)
export(get.stdout.nodes)
export(get.tool.info)
export(get.urls)
export(get.val.type)
export(get.variable.named)
export(get.variables.set)
export(get.variables.used)
export(prov.parse)
exportClasses(ProvInfo)
import(methods)
