# this script assumes the existance of fun and z, and is used as a source
# test case
w <- z + x
w <- fun(w,y)

# WILL REMOVE THIS ONCE BARBARA'S CODE TO FIX COLLAPSIBLE NODE DATA NDOES IS FIXED
z <- 0

source("source2.r")